#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_AVERAGE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_AVERAGE_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/average.hpp>

#endif
